@@ -1,9 +1,11 @@
+use std::time::Duration;
+
 use serenity::{
 	client::{bridge::gateway::GatewayIntents, ClientBuilder, Context, RawEventHandler},
 	model::event::Event,
 };
 
-use serenity_ctrlc::Ext;
+use serenity_ctrlc::{Disconnector, Ext};
 
 struct Handler;
 
@@ -25,7 +27,13 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
 		.intents(GatewayIntents::empty())
 		.raw_event_handler(Handler)
 		.await?
-		.ctrlc()?
+		.ctrlc_with(|dc| async {
+			println!("Disconnecting in 3 seconds..");
+			tokio::time::sleep(Duration::from_secs(3)).await;
+			println!("Disconnecting..");
+			Disconnector::disconnect_some(dc).await;
+			println!("Disconnected!");
+		})?
 		.start()
 		.await?;
 	Ok(())
